@@ -387,7 +387,7 @@ export function finishView (view) {
     const $ele = $(value).closest('pre')
     require.ensure([], function (require) {
       try {
-        const mermaid = require('mermaid')
+        const mermaid = require('mermaid').default
         mermaid.startOnLoad = false
         mermaid.mermaidAPI.parse($value.text())
         $ele.addClass('mermaid')
@@ -845,8 +845,9 @@ function imgPlayiframe (element, src) {
 
 const anchorForId = id => {
   const anchor = document.createElement('a')
+  anchor.ariaHidden = 'true'
   anchor.className = 'anchor hidden-xs'
-  anchor.href = `#${id}`
+  anchor.href = new URL(`${document.location.search}#${id}`, document.location).toString()
   anchor.innerHTML = '<i class="fa fa-link"></i>'
   anchor.title = id
   return anchor
@@ -1119,7 +1120,7 @@ md.renderer.rules.fence = (tokens, idx, options, env, self) => {
 // youtube
 const youtubePlugin = new Plugin(
   // regexp to match
-  /{%youtube\s*([\d\D]*?)\s*%}/,
+  /{%youtube\s*([\w-]{11})\s*%}/,
 
   (match, utils) => {
     const videoid = match[1]
@@ -1137,7 +1138,7 @@ const youtubePlugin = new Plugin(
 // vimeo
 const vimeoPlugin = new Plugin(
   // regexp to match
-  /{%vimeo\s*([\d\D]*?)\s*%}/,
+  /{%vimeo\s*(\d{6,11})\s*%}/,
 
   (match, utils) => {
     const videoid = match[1]
@@ -1152,7 +1153,7 @@ const vimeoPlugin = new Plugin(
 // gist
 const gistPlugin = new Plugin(
   // regexp to match
-  /{%gist\s*([\d\D]*?)\s*%}/,
+  /{%gist\s*(\w+\/\w+)\s*%}/,
 
   (match, utils) => {
     const gistid = match[1]
@@ -1170,7 +1171,7 @@ const tocPlugin = new Plugin(
 // slideshare
 const slidesharePlugin = new Plugin(
   // regexp to match
-  /{%slideshare\s*([\d\D]*?)\s*%}/,
+  /{%slideshare\s*(\w+\/[\w-]+)\s*%}/,
 
   (match, utils) => {
     const slideshareid = match[1]
@@ -1182,7 +1183,7 @@ const slidesharePlugin = new Plugin(
 // speakerdeck
 const speakerdeckPlugin = new Plugin(
   // regexp to match
-  /{%speakerdeck\s*([\d\D]*?)\s*%}/,
+  /{%speakerdeck\s*(\w+\/[\w-]+)\s*%}/,
 
   (match, utils) => {
     const speakerdeckid = match[1]
